@@ -57,11 +57,6 @@ $cmd = "cd $basedir ; perl ./build-files/version.pl __QGVDIAL_VERSION__ $qver";
 print "$cmd\n";
 system($cmd);
 
-# Fix the QML files
-$cmd = "cd $basedir ; perl ./build-files/fixqml.pl ./qml";
-print "$cmd\n";
-system($cmd);
-
 # Copy the correct pro file
 system("cp $basedir/build-files/pro.qgvnotify $basedir/qgvdial.pro");
 
